#[non_exhaustive]pub enum Event<'a> {
Magnifier {
active: WEnum<ActiveState>,
},
ScreenFilter {
inverted: WEnum<ActiveState>,
filter: WEnum<Filter>,
},
ScreenFilter2 {
inverted: WEnum<ActiveState>,
filter: WEnum<Filter>,
filter_state: WEnum<ActiveState>,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Magnifier
State of the screen magnifier
State of the screen magnifier.
This event will be emitted by the compositor when binding the protocol and whenever the state changes.
Fields
active: WEnum<ActiveState>If the screen magnifier is enabled
ScreenFilter
State of screen filtering
Parameters used for screen filtering.
This event will be emitted by the compositor when binding the protocol and whenever the state changes.
If a screen filter is used not known to the protocol or the bound version filter will be set to unknown.
Since version 3 this event will not be emitted anymore, instead use screen_filter2.
Only available since version 2 of the interface
Fields
inverted: WEnum<ActiveState>If the screen colors are inverted
ScreenFilter2
State of screen filtering
Parameters used for screen filtering.
This event will be emitted by the compositor when binding the protocol and whenever the state changes.
If a screen filter is used not known to the protocol or the bound version filter will be set to unknown.
The compositor must never send “disabled” as the “filter” argument.
Only available since version 3 of the interface
Fields
inverted: WEnum<ActiveState>If the screen colors are inverted
filter_state: WEnum<ActiveState>If the screen filter is active
Implementations