#[non_exhaustive]
pub enum Request { SetMagnifier { active: WEnum<ActiveState>, }, SetScreenFilter { inverted: WEnum<ActiveState>, filter: WEnum<Filter>, }, SetScreenFilter2 { inverted: WEnum<ActiveState>, filter: WEnum<Filter>, filter_state: WEnum<ActiveState>, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SetMagnifier

Set the screen magnifier on or off

Sets the state of the screen magnifier.

The client must not assume any requested changes are actually applied and should wait until the next magnifier event before updating it’s UI.

Fields

active: WEnum<ActiveState>

If the screen magnifier should be enabled



SetScreenFilter

Set screen filtering

Set the parameters for screen filtering.

If the filter is set to unknown, the compositor MUST not change the current state of the filter. This is to allow clients to update the inverted state, even if they don’t know about the current active filter.

The client must not assume any requested changes are actually applied and should wait until the next screen_filter event before updating it’s UI.

Send this request will raised a “deprecated” protocol error, if version 3 or higher was bound. Use set_screen_filter2 instead.

Only available since version 2 of the interface

Fields

inverted: WEnum<ActiveState>

If the screen colors should be inverted

filter: WEnum<Filter>

Which if any filter should be used



SetScreenFilter2

Set screen filtering

Set the parameters for screen filtering.

If the filter is set to unknown, the compositor MUST not change the currently set filter. This is to allow clients to update the inverted state or toggle the screen filter, even if they don’t know about the currently selected filter.

The client must not assume any requested changes are actually applied and should wait until the next screen_filter event before updating it’s UI.

The “deprecated” protocol error is raised, if “disabled” is set for “filter”.

Only available since version 3 of the interface

Fields

inverted: WEnum<ActiveState>

If the screen colors should be inverted

filter: WEnum<Filter>

Which if filter should be used

filter_state: WEnum<ActiveState>

If the screen filter should be active

Implementations

Source

impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message